@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Copyright 2015 by PyCLibrary Authors, see AUTHORS for more details.
+# Copyright 2015-2020 by PyCLibrary Authors, see AUTHORS for more details.
 #
 # Distributed under the terms of the MIT/X11 license.
 #
@@ -11,22 +11,18 @@ Used for extracting data such as macro definitions, variables, typedefs, and
 function signatures from C header files.
 
 """
-from __future__ import (division, unicode_literals, print_function,
-                        absolute_import)
-
 import sys
 import re
 import os
 import logging
 from inspect import cleandoc
-from future.utils import istext, isbytes
 from traceback import format_exc
 
 from .errors import DefinitionError
 from .utils import find_header
 
 # Import parsing elements
-from .thirdparty.pyparsing import \
+from pyparsing import \
     (ParserElement, ParseResults, Forward, Optional, Word, WordStart,
      WordEnd, Keyword, Regex, Literal, SkipTo, ZeroOrMore, OneOrMore,
      Group, LineEnd, quotedString, oneOf, nestedExpr,
@@ -322,7 +318,7 @@ def win_defs(version='1500'):
     header_files = ['WinNt.h', 'WinDef.h', 'WinBase.h', 'BaseTsd.h',
                     'WTypes.h', 'WinUser.h']
     if not CParser._init:
-        logger.warning('Automatic initialisation : OS is assumed to be win32')
+        logger.info('Automatic initialisation : OS is assumed to be win32')
         from .init import auto_init
         auto_init()
     d = os.path.dirname(__file__)
@@ -415,7 +411,7 @@ class CParser(object):
                  process_all=True, cache=None, check_cache_validity=True, **kwargs):
 
         if not self._init:
-            logger.warning('Automatic initialisation based on OS detection')
+            logger.info('Automatic initialisation based on OS detection')
             from .init import auto_init
             auto_init()
 
@@ -437,7 +433,7 @@ class CParser(object):
         self.files = {}
 
         if files is not None:
-            if istext(files) or isbytes(files):
+            if isinstance(files, str):
                 files = [files]
             for f in self.find_headers(files):
                 self.load_file(f, replace)
@@ -541,7 +537,7 @@ class CParser(object):
               - cache file must not be older than any source files
               - cache file must not be older than this library file
               - options recorded in cache must match options used to initialize
-              CParser
+                CParser
 
         Returns
         -------
@@ -551,8 +547,8 @@ class CParser(object):
         """
 
         # Make sure cache file exists
-        if not istext(cache_file):
-            raise ValueError("Cache file option must be a unicode.")
+        if not isinstance(cache_file, str):
+            raise ValueError("Cache file option must be a str.")
         if not os.path.isfile(cache_file):
             # If file doesn't exist, search for it in this module's path
             d = os.path.dirname(__file__)
@@ -667,14 +663,7 @@ class CParser(object):
             self.files[path] = None
             return False
 
-        if sys.version_info >= (3,):
-            open_mode = "r"
-        else:
-            # U causes all newline types to be converted to \n, but is the default from
-            # Python 3 on
-            open_mode = "rU"
-
-        with open(path, open_mode) as fd:
+        with open(path, "r") as fd:
             self.files[path] = fd.read()
 
         if replace is not None:
@@ -698,7 +687,7 @@ class CParser(object):
                 s += pformat(self.defs[k], indent=4) + "\n"
             else:
                 s += pformat(self.file_defs[filename][k]) + "\n"
-        return s       
+        return s
 
     def print_all(self, filename=None):
         """Print everything parsed from files. Useful for debugging.
@@ -1107,8 +1096,7 @@ class CParser(object):
         if extra_modifier is not None:
             type_ += extra_modifier
         type_.setParseAction(recombine)
-        self.type_spec = (type_qualifier('pre_qual') +
-                          type_("name"))
+        self.type_spec = Group(type_qualifier('pre_qual') + type_("name"))
 
         # --- Abstract declarators for use in function pointer arguments
         #   Thus begins the extremely hairy business of parsing C declarators.
@@ -1276,7 +1264,7 @@ class CParser(object):
             else:
                 ex = lambda x: (x[0],) if len(x)!=0 else (None,)
                 toks.append(tuple([self.process_type(a['type'],
-                                                     a['decl']) +
+                                                     a['decl'][0]) +
                                    ex(a['val']) for a in decl['args']]
                                   )
                             )
@@ -1308,19 +1296,20 @@ class CParser(object):
           declarator
         - basetype is the string representing the base type
         - modifiers can be:
-            - '*'    : pointer (multiple pointers "***" allowed)
-            - '&'    : reference
-            - '__X'  : calling convention (windows only). X can be 'cdecl' or
-              'stdcall'
+
+            - `*`    : pointer (multiple pointers `***` allowed)
+            - `&`    : reference
+            - `__X`  : calling convention (windows only). X can be `cdecl` or
+              `stdcall`
             - list   : array. Value(s) indicate the length of each array, -1
               for incomplete type.
             - tuple  : function, items are the output of processType for each
               function argument.
 
         Examples:
-          - int *x[10]            =>  ('x', ['int', [10], '*'])
-          - char fn(int x)         =>  ('fn', ['char', [('x', ['int'])]])
-          - struct s (*)(int, int*)   =>
+          - int *x[10]               =>  ('x', ['int', [10], '*'])
+          - char fn(int x)           =>  ('fn', ['char', [('x', ['int'])]])
+          - struct s (*)(int, int*)  =>
             (None, ["struct s", ((None, ['int']), (None, ['int', '*'])), '*'])
 
         """
@@ -1415,7 +1404,7 @@ class CParser(object):
                         break
                     n += 1
             else:
-                if istext(t.name):
+                if isinstance(t.name, str):
                     sname = t.name
                 else:
                     sname = t.name[0]
@@ -1500,7 +1489,7 @@ class CParser(object):
         """
         logger.debug("Eval: {}".format(toks))
         try:
-            if istext(toks) or isbytes(toks):
+            if isinstance(toks, str):
                 val = self.eval(toks, None, self.defs['values'])
             elif toks.array_values != '':
                 val = [self.eval(x, None, self.defs['values'])
@@ -1584,7 +1573,7 @@ class CParser(object):
             for t in fd:
                 typ = fd[t]
                 for k in typ:
-                    if istext(name):
+                    if isinstance(name, str):
                         if k == name:
                             res.append((f, t))
                     else:
@@ -1660,8 +1649,8 @@ rparen = Literal(")").ignore(quotedString).suppress()
 
 # Numbers
 int_strip = lambda t: t[0].rstrip('UL')
-hexint = Regex('[+-]?\s*0[xX][{}]+[UL]*'.format(hexnums)).setParseAction(int_strip)
-decint = Regex('[+-]?\s*[0-9]+[UL]*').setParseAction(int_strip)
+hexint = Regex(r'[+-]?\s*0[xX][{}]+[UL]*'.format(hexnums)).setParseAction(int_strip)
+decint = Regex(r'[+-]?\s*[0-9]+[UL]*').setParseAction(int_strip)
 integer = (hexint | decint)
 # The floating regex is ugly but it is because we do not want to match
 # integer to it.
